/**
 * $RCSfile: editor_plugin_src.js,v $
 * $Revision: 1.12 $
 * $Date: 2006/02/22 20:06:23 $
 *
 * @author Moxiecode
 * @copyright Copyright  2004-2006, Moxiecode Systems AB, All rights reserved.
 */

/* Import plugin specific language pack */
tinyMCE.importPluginLanguagePack('typo3link', 'en,de'); // <- Add a comma separated list of all supported languages


// Singleton class
var TinyMCE_typo3linkPlugin = {
	/**
	 * Returns information about the plugin as a name/value array.
	 * The current keys are longname, author, authorurl, infourl and version.
	 *
	 * @returns Name/value array containing information about the plugin.
	 * @type Array 
	 */
	getInfo : function() {
		return {
			longname : 'Typo3 Filebrowser',
			author : 'T.Schulze [outraxX]',
			authorurl : 'mailto:kontakt@outraxx.de',
			infourl : 'http://www.outraxx.de',
			version : "0.3"
		};
	},

	/**
	 * Gets executed when a TinyMCE editor instance is initialized.
	 *
	 * @param {TinyMCE_Control} Initialized TinyMCE editor control instance. 
	 */
	initInstance : function(inst) {
		// Register custom keyboard shortcut
		inst.addShortcut('ctrl', 'l', 'lang_typo3link_desc', 'mcetypo3link');
	},

	getControlHTML : function(cn) {
		switch (cn) {
			case "typo3link":
				return tinyMCE.getButtonHTML(cn, 'lang_typo3link_desc', '{$pluginurl}/images/image.gif', 'mcetypo3link', true);
		}

		return "";
	},


	execCommand : function(editor_id, element, command, user_interface, value) {
		// Handle commands
		switch (command) {
			// Remember to have the "mce" prefix for commands so they don't intersect with built in ones in the browser.
			case "mcetypo3link":
				fileBrowserCallBack("", "", "link", "");
				return true;
		}

		// Pass to next handler in chain
		return false;
	},

	handleNodeChange : function(editor_id, node, undo_index, undo_levels, visual_aid, any_selection) {
		if (node == null)
			return;

		do {
			if (node.nodeName == "A" && tinyMCE.getAttrib(node, 'href') != "") {
				tinyMCE.switchClass(editor_id + '_typo3link', 'mceButtonSelected');
				return true;
			}
		} while ((node = node.parentNode));

		if (any_selection) {
			tinyMCE.switchClass(editor_id + '_typo3link', 'mceButtonNormal');
			return true;
		}

		tinyMCE.switchClass(editor_id + '_typo3link', 'mceButtonDisabled');

		return true;
	}
};

// Adds the plugin class to the list of available TinyMCE plugins
tinyMCE.addPlugin("typo3link", TinyMCE_typo3linkPlugin);
